{% load i18n %}
<!-- Related Resources -->
<div class="block-level-v2 block-description" style="background: #f9f9f9; border-top: 1px solid #dcdcdc; padding-bottom: 80px;">
    <div class="container">

        <div>

            <!-- Section Header -->
            <div class="">
                <i class="center-icon rounded-x fa fa-exchange"></i>
                <div class="">
                    <h2 class="arches-report-section-header">{% trans "Related Resources" %}</h2>
                </div> 
            </div>

            <!-- Anchor for in=page navigation from "report options" menu -->
            <a href="evaluation" id="evaluation" style=""></a>

            <!-- Content -->
            <div class="row">
                
                <!-- Spacer -->
                <div class="hidden-sm hidden-md hidden-lg margin-bottom-20"></div>

                <!-- Related Resources -->
                <div class="col-xs-12">
                    <div class="right-inner arches-box-grey-border margin-bottom-40">
                        
                        <!-- Related Historic Resources Section -->
                        <div class="row">

                            <!-- Section Header -->
                            <div class="col-sm-4">
                                <h3 class="arches-report-subsection">
                                    {% trans "Related Historic Resources" %}
                                </h3>
                            </div>
                            <!-- End Section Header -->

                            <!-- Section Content -->
                            <div class="col-sm-8 arches-report-group-spacer">

                                <!-- Spacer -->
                                <div class="arches-report-spacer hidden-xs"></div>

                                <!-- related heritage resources -->
                                <div class="row">
                                    <div class="col-xs-12">

                                        <dl>
                                            {% for related_resource in related_resource_dict.HERITAGE_RESOURCE %}
                                                <dd class="arches-report-subsection-item">
                                                    <a href="{% url 'report' related_resource.entityid %}" class="" title="{% trans "View Report" %}">
                                                        {{related_resource.primaryname}}
                                                    </a>
                                                    <span class="arches-report-subsection-item-type">
                                                        {{related_resource.relationship}}
                                                    </span>
                                                </dd>

                                                {% empty %}
                                                    <dd class="arches-report-subsection-item">
                                                        {% trans "None" %}
                                                    </dd>                                                        
                                            {% endfor %} 
                                        </dl>
                                        
                                    </div>
                                </div>
                            </div>
                            <!-- End Section Content-->
                        </div>
                        <!-- End Related Historic Resources Section -->


                        <hr class="devider margin-top-10" style="margin-bottom: 5px;">


                        <!-- Related Historic Groups -->
                        <div class="row">

                            <!-- Section Header -->
                            <div class="col-sm-4">
                                <h3 class="arches-report-subsection">
                                    {% trans "Related Historic Districts" %}
                                </h3>
                            </div>
                            <!-- End Section Header -->

                            <!-- Section Content -->
                            <div class="col-sm-8 arches-report-group-spacer">

                                <!-- Spacer -->
                                <div class="arches-report-spacer hidden-xs"></div>
                            
                                <!-- resource groups -->
                                <div class="row">
                                    <div class="col-xs-12">
                                        <dl>                               
                                            
                                            {% for related_resource in related_resource_dict.HERITAGE_RESOURCE_GROUP %}
                                                <dd class="arches-report-subsection-item">
                                                    <a href="{% url 'report' related_resource.entityid %}" class="" title="{% trans "View Report" %}">
                                                        {{related_resource.primaryname}}
                                                    </a>
                                                    <span class="arches-report-subsection-item-type">
                                                        {{related_resource.relationship}}
                                                    </span>
                                                </dd> 

                                                {% empty %}
                                                    <dd class="arches-report-subsection-item">
                                                        {% trans "None" %}
                                                    </dd>                                                        
                                            {% endfor %} 
                                        </dl>
                                        
                                    </div>
                                </div>
                            </div>
                            <!-- End Section Content-->
                        </div>
                        <!-- End Related HistoricGroups Section -->


                        <hr class="devider margin-top-10" style="margin-bottom: 5px;">


                        <!-- Related Activities -->
                        <div class="row">

                            <!-- Section Header -->
                            <div class="col-sm-4">
                                <h3 class="arches-report-subsection">
                                    {% trans "Related Activities" %}
                                </h3>
                            </div>
                            <!-- End Section Header -->

                            <!-- Section Content -->
                            <div class="col-sm-8 arches-report-group-spacer">

                                <!-- Spacer -->
                                <div class="arches-report-spacer hidden-xs"></div>

                                <!-- related activities -->
                                <div class="row">
                                    <div class="col-xs-12">

                                        <dl>

                                            {% for related_resource in related_resource_dict.ACTIVITY %}
                                                <dd class="arches-report-subsection-item">
                                                    <a href="{% url 'report' related_resource.entityid %}" class="" title="{% trans "View Report" %}">
                                                        {{related_resource.primaryname}}
                                                    </a>
                                                    <span class="arches-report-subsection-item-type">
                                                        {{related_resource.relationship}}
                                                    </span>
                                                </dd> 

                                                {% empty %}
                                                    <dd class="arches-report-subsection-item">
                                                        {% trans "None" %}
                                                    </dd>                                                        
                                            {% endfor %} 
                                        </dl>
                                        
                                    </div>
                                </div>
                            </div>
                            <!-- End Section Content-->
                        </div>
                        <!-- End Related Activities -->


                        <hr class="devider margin-top-10" style="margin-bottom: 5px;">


                        <!-- Related Historic Events -->
                        <div class="row">

                            <!-- Section Header -->
                            <div class="col-sm-4">
                                <h3 class="arches-report-subsection">
                                    {% trans "Related Historic Events" %}
                                </h3>
                            </div>
                            <!-- End Section Header -->

                            <!-- Section Content -->
                            <div class="col-sm-8 arches-report-group-spacer">

                                <!-- Spacer -->
                                <div class="arches-report-spacer hidden-xs"></div>

                                <!-- related historic events -->
                                <div class="row">
                                    <div class="col-xs-12">

                                        <dl>
                                            {% for related_resource in related_resource_dict.HISTORICAL_EVENT %}
                                                <dd class="arches-report-subsection-item">
                                                    <a href="{% url 'report' related_resource.entityid %}" class="" title="{% trans "View Report" %}">
                                                        {{related_resource.primaryname}}
                                                    </a>
                                                    <span class="arches-report-subsection-item-type">
                                                        {{related_resource.relationship}}
                                                    </span>
                                                </dd> 

                                                {% empty %}
                                                    <dd class="arches-report-subsection-item">
                                                        {% trans "None" %}
                                                    </dd>                                                        
                                            {% endfor %} 
                                        </dl>
                                        
                                    </div>
                                </div>
                            </div>
                            <!-- End Section Content-->
                        </div>
                        <!-- End Related Historic Events Section -->


                        <hr class="devider margin-top-10" style="margin-bottom: 5px;">


                        <!-- Related Actors -->
                        <div class="row">

                            <!-- Section Header -->
                            <div class="col-sm-4">
                                <h3 class="arches-report-subsection">{% trans "Related People/Organizations" %}</h3>
                            </div>
                            <!-- End Section Header -->

                            <!-- Section Content -->
                            <div class="col-sm-8 arches-report-group-spacer">

                                <!-- Spacer -->
                                <div class="arches-report-spacer hidden-xs"></div>

                                <!-- related actors -->
                                <div class="row">
                                    <div class="col-xs-12">

                                        <dl> 
                                            {% for related_resource in related_resource_dict.ACTOR %}
                                                <dd class="arches-report-subsection-item">
                                                    <a href="{% url 'report' related_resource.entityid %}" class="" title="{% trans "View Report" %}">
                                                        {{related_resource.primaryname}}
                                                    </a>
                                                    <span class="arches-report-subsection-item-type">
                                                        {{related_resource.relationship}}
                                                    </span> 
                                                </dd>

                                                {% empty %}
                                                    <dd class="arches-report-subsection-item">
                                                        {% trans "None" %}
                                                    </dd>                                                        
                                            {% endfor %} 
                                        </dl>
                                        
                                    </div>
                                </div>
                            </div>
                            <!-- End Section Content-->
                        </div>
                        <!-- End Related Actors Section -->


                        <hr class="devider margin-top-10" style="margin-bottom: 5px;">


                        <!-- Related Information Objects -->
                        <div class="row">

                            <!-- Section Header -->
                            <div class="col-sm-4">
                                <h3 class="arches-report-subsection">{% trans "Related Information Resources" %}</h3>
                            </div>
                            <!-- End Section Header -->

                            <!-- Section Content -->
                            <div class="col-sm-8 arches-report-group-spacer" style="padding-left: 22px;">

                                <!-- Spacer -->
                                <div class="arches-report-spacer hidden-xs"></div>

                                <div class="row">
                                    <div class="col-xs-12">

                                        <dl>
                                            <dt>
                                                <h5 class="arches-report-subsection-title arches-report-spacer">
                                                    {% trans "Images" %}
                                                </h5>
                                            </dt>

                                            <!-- Links for Image Gallery Supply Image in the href, thumbnails in the img tags -->
                                            {% for related_resource in related_resource_dict.INFORMATION_RESOURCE_IMAGE %}
                                                <dd class="arches-report-subsection-item">
                                                    <a href="{% url 'report' related_resource.entityid %}" title="{% trans "View Report" %}">
                                                        <img src="{{related_resource.thumbnail}}" alt="" class="arches-report-image-thumbnail" style="width: 25%; margin-bottom: 20px; border: solid 1px #999;" onerror="this.src='{{STATIC_URL}}img/photo_missing.png';">
                                                    </a>
                                                </dd>

                                                {% empty %}
                                                    <dd class="arches-report-subsection-item">
                                                        {% trans "None" %}
                                                    </dd>                                                        
                                            {% endfor %}
                                            
                                        </dl>
                                    </div>
                                </div>

                                <div class="row">
                               
                                    <div class="col-xs-12">
                                        <dl>
                                            <dt>
                                                <h5 class="arches-report-subsection-title">
                                                    {% trans "Documents" %}
                                                </h5>
                                            </dt>

                                            {% for related_resource in related_resource_dict.INFORMATION_RESOURCE_DOCUMENT %}
                                                <dd class="arches-report-subsection-item">
                                                    <a href="{% url 'report' related_resource.entityid %}" title="{% trans "View Report" %}">
                                                        {{related_resource.primaryname}}
                                                    </a>

                                                    <span class="arches-report-subsection-item-type">
                                                        ({{related_resource.relationship}})
                                                    </span>
                                                </dd>

                                                {% empty %}
                                                    <dd class="arches-report-subsection-item">
                                                        {% trans "None" %}
                                                    </dd>                                                        
                                            {% endfor %} 
                          
                                        </dl>
                                    </div>
                                </div>
                                <!-- End List of Related Resources (Documents)-->
                            </div>
                            <!-- End Section Content-->
                        </div>
                        <!-- End Related Information Objects Section -->

                    </div>
                </div>
                <!-- End Related Historic Resources -->
            </div>   
        </div>
    </div> 
</div>    
<!-- End Related Resource Container -->